import React, { useState } from "react";
import { Form, Row, Col } from "react-bootstrap";
import ProductPicker from "../ProductPicker";
import Fetcher from "../Fetcher";

function date2string(date) {
  return date.toISOString().split("T")[0];
}

function daysAfterNow(days) {
  let date = new Date();
  date.setDate(date.getDate() + days);
  return date;
}

function order2picks(order) {
  return order.products.map((p) => {
    return {
      code: p.code,
      name: p.product.name,
      price: p.price,
    };
  });
}

function genBody(name, description, deadline, picks) {
  const products = picks.map((p) => {
    return { code: p.code, price: p.price };
  });
  const deadlineDate = new Date(deadline);
  return { name, description, deadline: deadlineDate, products };
}

function OrderEditor(props) {
  const [name, _setName] = useState(props.order ? props.order.name : "");
  const [description, _setDescription] = useState(
    props.order ? props.order.description : ""
  );
  const [deadline, _setDeadline] = useState(
    props.order
      ? date2string(new Date(props.order.deadline))
      : date2string(daysAfterNow(3))
  );
  const [picks, _setPicks] = useState(
    props.order ? order2picks(props.order) : []
  );
  const [prevOrders, setPrevOrders] = useState(null);

  const setName = (name) => {
    _setName(name);
    const body = genBody(name, description, deadline, picks);
    props.onChange(body);
  };
  const setDescription = (description) => {
    _setDescription(description);
    const body = genBody(name, description, deadline, picks);
    props.onChange(body);
  };
  const setDeadline = (str) => {
    _setDeadline(str);
    const body = genBody(name, description, deadline, picks);
    props.onChange(body);
  };
  const setPicks = (picks) => {
    _setPicks(picks);
    const body = genBody(name, description, deadline, picks);
    props.onChange(body);
  };

  const fillOrder = (name) => {
    if (!name) {
      return;
    }

    const prevOrder = prevOrders.find((o) => o.name === name);
    _setName(name);
    _setDescription(prevOrder.description);
    const prevPicks = order2picks(prevOrder);
    setPicks(prevPicks);

    const body = genBody(name, prevOrder.description, deadline, prevPicks);
    props.onChange(body);
  };

  const orderOptions = prevOrders
    ? [<option key=""></option>].concat(
        prevOrders.map((o) => <option key={o.name}>{o.name}</option>)
      )
    : "";

  let order_picker;
  if (!props.order) {
    order_picker = (
      <div>
        <Form.Group as={Row}>
          <Form.Label as="legend" column sm={3}>
            Repetir pedido
          </Form.Label>
          <Col sm={9}>
            <Fetcher url="/api/order/picks" onFetch={setPrevOrders}>
              <Form.Control
                as="select"
                onChange={(e) => fillOrder(e.target.value)}
              >
                {orderOptions}
              </Form.Control>
            </Fetcher>
          </Col>
        </Form.Group>
        <hr />
      </div>
    );
  }

  return (
    <div>
      {order_picker}
      <Form.Group as={Row}>
        <Form.Label as="legend" column sm={3}>
          Nombre
        </Form.Label>
        <Col sm={9}>
          <Form.Control
            placeholder="nombre del pedido"
            value={name}
            onChange={(e) => setName(e.target.value)}
          />
        </Col>
      </Form.Group>
      <Form.Group as={Row}>
        <Form.Label as="legend" column sm={3}>
          Descripción
        </Form.Label>
        <Col sm={9}>
          <Form.Control
            as="textarea"
            value={description}
            onChange={(e) => setDescription(e.target.value)}
          />
        </Col>
      </Form.Group>
      <Form.Group as={Row}>
        <Form.Label as="legend" column sm={3}>
          Fecha límite
        </Form.Label>
        <Col sm={9}>
          <Form.Control
            type="date"
            value={deadline}
            onChange={(e) => setDeadline(e.target.value)}
            min={date2string(daysAfterNow(1))}
          />
        </Col>
      </Form.Group>
      <ProductPicker picks={picks} setPicks={setPicks} price />
    </div>
  );
}

export default OrderEditor;
